.. _revisions:

=========
Revisions
=========

Accessing Revisions
===================

Revisions are maintained every time a change is made. To access the versions, open up the story and click on the History button in the upper-left corner of the window, just left of the View on Site button.

.. image:: images/history_btn.png
   :alt: The History and View on site buttons.

The history list shows each version of this story. The blue timestamps are clickable and lead to a page detailing the content. The list also shows who made the change and a brief description of what they changed. To continue, select a revision from the list by clicking on the timestamp.

.. image:: images/history_list.png
   :alt: The history list

Each field of the story is shown with the values it contained in that version. It is not editable. You can leave the screen by clicking the browser's back arrow, or the "Cancel" button at the bottom of the screen.


Reverting to a Previous Version
===============================

Once you have opened up a previous version and want to revert back to it, click on the "Revert to this version" button.

.. image:: images/history_save_btn.png


Recovering a Deleted Story
==========================

In the Stories listing, click on the "Recover Deleted Story" button in the upper-right corner of the page.

.. image:: images/recover_btn.png

Then select a deleted story from the list by clicking on the timestamp.

.. image:: images/recover_list.png

The deleted story will open up as if you were editing it. Click the "Save" button to finish the recovery.